@@ -13,17 +13,13 @@
 ##############################################################################
 """Interfaces for session utility.
 
-$Id: interfaces.py 80054 2007-09-25 21:28:40Z rogerineichen $
+$Id: interfaces.py 116073 2010-09-01 10:39:46Z menesis $
 """
 
-import zope.deferredimport
-
-zope.deferredimport.deprecated(
-    "It has moved to zope.session.interfaces  This reference will be gone sometimes.",
-    IClientIdManager = 'zope.session.interfaces:IClientIdManager',
-    IClientId = 'zope.session.interfaces:IClientId',
-    ISessionDataContainer = 'zope.session.interfaces:ISessionDataContainer',
-    ISession = 'zope.session.interfaces:ISession',
-    ISessionData = 'zope.session.interfaces:ISessionData',
-    ISessionPkgData = 'zope.session.interfaces:ISessionPkgData',
-    )
+# BBB
+from zope.session.interfaces import (IClientIdManager,
+                                     IClientId,
+                                     ISessionDataContainer,
+                                     ISession,
+                                     ISessionData,
+                                     ISessionPkgData)
