@@ -13,11 +13,11 @@
 ##############################################################################
 """Session tests
 
-$Id: tests.py 95587 2009-01-30 16:42:31Z thefunny42 $
+$Id: tests.py 116098 2010-09-01 14:54:42Z menesis $
 """
 from cStringIO import StringIO
 import unittest, os, os.path
-from zope.testing import doctest
+import doctest
 from zope.app.testing import ztapi, placelesssetup
 import transaction
 
